TaskCommands

Enum TaskCommands 

pub enum TaskCommands {
Show 16 variants List { list: String, status: Option<Vec<String>>, assignee: Option<Vec<String>>, tag: Option<Vec<String>>, include_closed: bool, order_by: Option<String>, reverse: bool, }, Search { space: Option<String>, folder: Option<String>, list: Option<String>, status: Option<Vec<String>>, assignee: Option<Vec<String>>, tag: Option<Vec<String>>, }, Get { id: Option<String>, subtasks: bool, custom_task_id: bool, }, Create { list: String, name: String, description: Option<String>, status: Option<String>, priority: Option<u8>, assignee: Option<Vec<String>>, tag: Option<Vec<String>>, due_date: Option<String>, parent: Option<String>, }, Update { id: Option<String>, name: Option<String>, status: Option<String>, priority: Option<u8>, add_assignee: Option<Vec<String>>, rem_assignee: Option<Vec<String>>, description: Option<String>, }, Delete { id: Option<String>, }, TimeInStatus { ids: Vec<String>, }, AddTag { task_or_tag: String, tag_name: Option<String>, }, RemoveTag { task_or_tag: String, tag_name: Option<String>, }, AddDep { id: Option<String>, depends_on: Option<String>, dependency_of: Option<String>, }, RemoveDep { id: Option<String>, depends_on: Option<String>, dependency_of: Option<String>, }, Link { id: String, target_id: String, }, Unlink { id: String, target_id: String, }, Move { list: String, id: Option<String>, }, SetEstimate { assignee: String, time: u64, id: Option<String>, }, ReplaceEstimates { assignee: String, time: u64, id: Option<String>, },
}

Variants



List

List tasks in a list

Fields

list: String

List ID

status: Option<Vec<String>>

Filter by status

assignee: Option<Vec<String>>

Filter by assignee

tag: Option<Vec<String>>

Filter by tag

include_closed: bool

Include closed tasks

order_by: Option<String>

Order by field

reverse: bool

Reverse sort order



Search

Search tasks across workspace

Fields

space: Option<String>

Filter by space

folder: Option<String>

Filter by folder

list: Option<String>

Filter by list

status: Option<Vec<String>>

Filter by status

assignee: Option<Vec<String>>

Filter by assignee

tag: Option<Vec<String>>

Filter by tag



Get

Get task details

Fields

id: Option<String>

Task ID (auto-detected from git branch if omitted)

subtasks: bool

Include subtasks

custom_task_id: bool

Treat ID as custom task ID



Create

Create a task

Fields

list: String

List ID

name: String

Task name

description: Option<String>

Description

status: Option<String>

Status

priority: Option<u8>

Priority (1=urgent, 2=high, 3=normal, 4=low)

assignee: Option<Vec<String>>

Assignee user ID

tag: Option<Vec<String>>

Tag name

due_date: Option<String>

Due date (YYYY-MM-DD)

parent: Option<String>

Parent task ID (creates subtask)



Update

Update a task

Fields

id: Option<String>

Task ID (auto-detected from git branch if omitted)

name: Option<String>

New name

status: Option<String>

New status

priority: Option<u8>

New priority (1-4)

add_assignee: Option<Vec<String>>

Add assignee

rem_assignee: Option<Vec<String>>

Remove assignee

description: Option<String>

New description



Delete

Delete a task (explicit ID required — never auto-detects from branch)

Fields

id: Option<String>

Task ID



TimeInStatus

Get time in status for task(s)

Fields

ids: Vec<String>

Task ID(s) — multiple IDs triggers bulk mode



AddTag

Add a tag to a task. Usage: add-tag <task_id> <tag_name> OR add-tag <tag_name> (task auto-detected from branch)

Fields

task_or_tag: String

Task ID (or tag name if only one arg is given)

tag_name: Option<String>

Tag name (when task_or_tag is a task ID)



RemoveTag

Remove a tag from a task. Usage: remove-tag <task_id> <tag_name> OR remove-tag <tag_name> (task auto-detected)

Fields

task_or_tag: String

Task ID (or tag name if only one arg is given)

tag_name: Option<String>

Tag name (when task_or_tag is a task ID)



AddDep

Add a dependency to a task

Fields

id: Option<String>

Task ID (auto-detected from git branch if omitted)

depends_on: Option<String>

This task depends on another task (task is a blocker)

dependency_of: Option<String>

This task is a dependency of another task (task is blocked by)



RemoveDep

Remove a dependency from a task

Fields

id: Option<String>

Task ID (auto-detected from git branch if omitted)

depends_on: Option<String>

Remove depends-on relationship with this task ID

dependency_of: Option<String>

Remove dependency-of relationship with this task ID

Link two tasks together

Fields

id: String

Task ID

target_id: String

Target task ID to link to

Unlink two tasks

Fields

id: String

Task ID

target_id: String

Target task ID to unlink from



Move

Move a task to a different list (v3)

Fields

list: String

Destination list ID

id: Option<String>

Task ID (auto-detected from git branch if omitted)



SetEstimate

Set per-user time estimate on a task (v3)

Fields

assignee: String

Assignee user ID

time: u64

Time estimate in milliseconds

id: Option<String>

Task ID (auto-detected from git branch if omitted)



ReplaceEstimates

Replace all per-user time estimates on a task (v3)

Fields

assignee: String

Assignee user ID

time: u64

Time estimate in milliseconds

id: Option<String>

Task ID (auto-detected from git branch if omitted)