Module mcp

Module mcp 

Modules

classify
Classification of MCP tool names into (Class, group).
filter
Runtime filter for the MCP tool list.

Functions

filtered_tool_list
Returns tool_list() with any tool the filter disallows removed.
handle_tools_call_early
Inspects a tools/call request and returns a JSON-RPC response when the request can be resolved WITHOUT executing the tool itself (missing tool name, or tool is filtered out). Returns None when the caller should proceed to invoke the tool.
serve
tool_list