handle_tools_call_early

Function handle_tools_call_early 

pub fn handle_tools_call_early(
    id: &Value,
    params: &Value,
    filter: &Filter,
) -> Option<Value>
Inspects a tools/call request and returns a JSON-RPC response when the request can be resolved WITHOUT executing the tool itself (missing tool name, or tool is filtered out). Returns None when the caller should proceed to invoke the tool.