Module mcp
clickup_
cli
0.9.1
Module mcp
Module Items
Modules
Functions
In crate clickup_
cli
clickup_cli
Module
mcp
Modules

classify
Classification of MCP tool names into (Class, group).
filter
Runtime filter for the MCP tool list.
Functions

filtered_
tool_
list
Returns
tool_list()
with any tool the filter disallows removed.
handle_
tools_
call_
early
Inspects a
tools/call
request and returns a JSON-RPC response when the request can be resolved WITHOUT executing the tool itself (missing tool name, or tool is filtered out). Returns
None
when the caller should proceed to invoke the tool.
serve
tool_
list